@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from requests import Session
 
-from patterns.cli.services.api import Endpoints, get_json
+from patterns.cli.services.api import Endpoints, get_json, patch
 
 
 def get_graph_by_slug(
@@ -15,7 +15,11 @@ def get_graph_by_uid(graph_uid: str, session: Session = None) -> dict:
     return get_json(Endpoints.graphs_latest(graph_uid), session=session)
 
 
-def get_graph_version_by_id(graph_version_uid, session: Session = None) -> dict:
+def update_graph(graph_uid: str, public: bool):
+    patch(Endpoints.graph_update(graph_uid), json={"public": public})
+
+
+def get_graph_version_by_uid(graph_version_uid, session: Session = None) -> dict:
     return get_json(Endpoints.graph_version_by_id(graph_version_uid), session=session)
 
 
